var languageNames = {
"en-US": "Angielski (USA)",
"am": "Amharski",
"ar": "Arabski",
"ast": "Asturyjski",
"bg": "Bułgarski",
"bn": "Bengalski",
"bn-IN": "Bengalski (Indie)",
"bo": "Tybetański",
"bs": "Bośniacki",
"ca": "Kataloński",
"ca-valencia": "Walencki kataloński",
"cs": "Czeski",
"da": "Duński",
"de": "Niemiecki",
"dz": "Dzongkha",
"el": "Grecki",
"en-GB": "Angielski (UK)",
"en-ZA": "Angielski (RPA)",
"eo": "Esperanto",
"es": "Hszpański",
"et": "Estoński",
"eu": "Baskijski",
"fi": "Fiński",
"fr": "Francuski",
"gl": "Galicyjski",
"gu": "Gudżarati",
"he": "Hebrajski",
"hi": "Hinduski",
"hr": "Chorwacki",
"hu": "Węgierski",
"id": "Indonezyjski",
"is": "Islandzki",
"it": "Włoski",
"ja": "Japoński",
"ka": "Gruziński",
"km": "Khmerski",
"ko": "Koreański",
"lo": "Laotański",
"lt": "Litewski",
"lv": "Łotewski",
"mk": "Macedoński",
"nb": "Norweski (bokmål)",
"ne": "Nepalski",
"nl": "Holenderski",
"nn": "Norweski (nynorsk)‎",
"om": "Oromo",
"pl": "Polski",
"pt": "Portugalski",
"pt-BR": "Portugalski brazylijski",
"ro": "Rumuński",
"ru": "Rosyjski",
"si": "Sinhala",
"sid": "Sidama",
"sk": "Słowacki",
"sl": "Słoweński",
"sq": "Albański",
"sv": "Szwedzki",
"ta": "Tamilski",
"tg": "Tadżycki",
"tr": "Turecki",
"ug": "Ujgurski",
"uk": "Ukraiński",
"vi": "Wietnamski",
"zh-CN": "Chiński (uproszczony)",
"zh-TW": "Chiński (tradycyjny)",
};
